@@ -5,6 +5,8 @@
     Copyright (c) 1999-2001 the KNode authors.
     See file AUTHORS for details
 
+    Rewritten for Quanta Plus: (C) 2002, 2003 Andras Mantia <amantia@kde.org>
+
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
@@ -17,8 +19,9 @@
 #ifndef KQAPPLICATION_H
 #define KQAPPLICATION_H
 
-#include <kuniqueapp.h>
+#include <kuniqueapplication.h>
 
+class KCmdLineArgs;
 
 class KSplash : public QFrame
 {
@@ -27,20 +30,35 @@ class KSplash : public QFrame
   public:
     KSplash();
     ~KSplash();
-
 };
 
-class KQApplication : public KApplication
+class KQApplicationPrivate
+{
+  public:
+    KQApplicationPrivate():splash(0L){};
+    ~KQApplicationPrivate() {};
+
+  protected:
+    void init();
+
+    KSplash *splash;
+    KCmdLineArgs *args;
+};
+
+class KQApplication : public KApplication, KQApplicationPrivate
 {
   Q_OBJECT
 
   public:
     KQApplication();
     ~KQApplication();
-
+  public slots:
+    /** No descriptions */
+    void slotInit();
+    void slotSplashTimeout();
 };
 
-class KQUniqueApplication : public KUniqueApplication
+class KQUniqueApplication : public KUniqueApplication, KQApplicationPrivate
 {
   Q_OBJECT
 
@@ -48,10 +66,13 @@ class KQUniqueApplication : public KUniqueApplication
     KQUniqueApplication();
     ~KQUniqueApplication();
 
-    /** Create new instance of KNode. Make the existing
-        main window active if KNode is already running */
+    /** Create new instance of Quanta. Make the existing
+        main window active if Quanta is already running */
     int newInstance();
-
+  public slots:
+    /** No descriptions */
+    void slotInit();
+    void slotSplashTimeout();
 };
 
 #endif
